const cvs = document.getElementById("canvas");
const ctx = cvs.getContext("2d");
const w = 270;
const h = 480;

ctx.textBaseline = "middle";

function clear() {
    ctx.save();
    ctx.fillStyle = "white";
    ctx.fillRect(0, 0, w, h);
    ctx.restore();
}

function txtWidth(txt) {
    return ctx.measureText(txt).width;
}

function text(txt, x, y) {
    ctx.fillText(txt, x - txtWidth(txt) / 2, y);
}

class Button {
    update(txt, x, y, disabled, hover) {
        ctx.save();
        ctx.font = "28px serif";
        ctx.fillStyle = disabled ? "#FCC" : (hover ? "#999" : "#CCC");

        this.x = x;
        this.y = y;
        this.txt = txt;
        this._disabled = disabled;
        this._hover = hover;
        this.width = txtWidth(txt) + 64;
        this.height = 28 + 28;

        this.left   = this.x - this.width  / 2;
        this.right  = this.x + this.width  / 2;
        this.top    = this.y - this.height / 2;
        this.bottom = this.y + this.height / 2;

        ctx.fillRect(this.left, this.top, this.width, this.height);
        ctx.restore();

        ctx.save();
        if (disabled) ctx.fillStyle = "gray";
        ctx.font = "28px serif";
        text(txt, x, y);
        ctx.restore();
    }

    constructor(txt, x, y, disabled) {
        this.update(txt, x, y, disabled);
    }

    get disabled() {
        return this._disabled;
    }

    set disabled(dis) {
        this.update(this.txt, this.x, this.y, dis);
    }

    hover(x, y) {
        if (x >= this.left && x <= this.right && y >= this.top && y <= this.bottom) {
            this.update(this.txt, this.x, this.y, this.disabled, true);
            return true;
        }

        this.update(this.txt, this.x, this.y, this.disabled);
        return false;
    }

    mousedown(x, y) {
        if (!this.disabled && x >= this.left && x <= this.right && y >= this.top && y <= this.bottom) {
            (this.action || function nop() {})();
        }
    }
}

const imgClock = new Image();
imgClock.src = "./icons/baseline_access_time_black_48dp.png";

const imgFlag = new Image();
imgFlag.src = "./icons/round_outlined_flag_black_48dp.png";
